@@ -157,7 +157,38 @@ class PrivateBucket(
         :param website_routing_rules: Rules that define when a redirect is applied and the redirect behavior. Default: - No redirection rules.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(PrivateBucket.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                access_control: typing.Optional[aws_cdk.aws_s3.BucketAccessControl] = None,
+                auto_delete_objects: typing.Optional[builtins.bool] = None,
+                block_public_access: typing.Optional[aws_cdk.aws_s3.BlockPublicAccess] = None,
+                bucket_key_enabled: typing.Optional[builtins.bool] = None,
+                bucket_name: typing.Optional[builtins.str] = None,
+                cors: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.CorsRule, typing.Dict[str, typing.Any]]]] = None,
+                encryption: typing.Optional[aws_cdk.aws_s3.BucketEncryption] = None,
+                encryption_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
+                enforce_ssl: typing.Optional[builtins.bool] = None,
+                event_bridge_enabled: typing.Optional[builtins.bool] = None,
+                intelligent_tiering_configurations: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.IntelligentTieringConfiguration, typing.Dict[str, typing.Any]]]] = None,
+                inventories: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.Inventory, typing.Dict[str, typing.Any]]]] = None,
+                lifecycle_rules: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.LifecycleRule, typing.Dict[str, typing.Any]]]] = None,
+                metrics: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.BucketMetrics, typing.Dict[str, typing.Any]]]] = None,
+                object_ownership: typing.Optional[aws_cdk.aws_s3.ObjectOwnership] = None,
+                public_read_access: typing.Optional[builtins.bool] = None,
+                removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
+                server_access_logs_bucket: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+                server_access_logs_prefix: typing.Optional[builtins.str] = None,
+                transfer_acceleration: typing.Optional[builtins.bool] = None,
+                versioned: typing.Optional[builtins.bool] = None,
+                website_error_document: typing.Optional[builtins.str] = None,
+                website_index_document: typing.Optional[builtins.str] = None,
+                website_redirect: typing.Optional[typing.Union[aws_cdk.aws_s3.RedirectTarget, typing.Dict[str, typing.Any]]] = None,
+                website_routing_rules: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.RoutingRule, typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = PrivateBucketProps(
@@ -282,7 +313,36 @@ class PrivateBucketProps(aws_cdk.aws_s3.BucketProps):
         if isinstance(website_redirect, dict):
             website_redirect = aws_cdk.aws_s3.RedirectTarget(**website_redirect)
         if __debug__:
-            type_hints = typing.get_type_hints(PrivateBucketProps.__init__)
+            def stub(
+                *,
+                access_control: typing.Optional[aws_cdk.aws_s3.BucketAccessControl] = None,
+                auto_delete_objects: typing.Optional[builtins.bool] = None,
+                block_public_access: typing.Optional[aws_cdk.aws_s3.BlockPublicAccess] = None,
+                bucket_key_enabled: typing.Optional[builtins.bool] = None,
+                bucket_name: typing.Optional[builtins.str] = None,
+                cors: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.CorsRule, typing.Dict[str, typing.Any]]]] = None,
+                encryption: typing.Optional[aws_cdk.aws_s3.BucketEncryption] = None,
+                encryption_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
+                enforce_ssl: typing.Optional[builtins.bool] = None,
+                event_bridge_enabled: typing.Optional[builtins.bool] = None,
+                intelligent_tiering_configurations: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.IntelligentTieringConfiguration, typing.Dict[str, typing.Any]]]] = None,
+                inventories: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.Inventory, typing.Dict[str, typing.Any]]]] = None,
+                lifecycle_rules: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.LifecycleRule, typing.Dict[str, typing.Any]]]] = None,
+                metrics: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.BucketMetrics, typing.Dict[str, typing.Any]]]] = None,
+                object_ownership: typing.Optional[aws_cdk.aws_s3.ObjectOwnership] = None,
+                public_read_access: typing.Optional[builtins.bool] = None,
+                removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
+                server_access_logs_bucket: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+                server_access_logs_prefix: typing.Optional[builtins.str] = None,
+                transfer_acceleration: typing.Optional[builtins.bool] = None,
+                versioned: typing.Optional[builtins.bool] = None,
+                website_error_document: typing.Optional[builtins.str] = None,
+                website_index_document: typing.Optional[builtins.str] = None,
+                website_redirect: typing.Optional[typing.Union[aws_cdk.aws_s3.RedirectTarget, typing.Dict[str, typing.Any]]] = None,
+                website_routing_rules: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_s3.RoutingRule, typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument access_control", value=access_control, expected_type=type_hints["access_control"])
             check_type(argname="argument auto_delete_objects", value=auto_delete_objects, expected_type=type_hints["auto_delete_objects"])
             check_type(argname="argument block_public_access", value=block_public_access, expected_type=type_hints["block_public_access"])
